==> RandomFieldsUtils_1.0.11.tar.gz: RandomFieldsUtils/src/AutoRandomFieldsUtils.cc <==
/*
Authors
Martin Schlather, schlather@math.uni-mannheim.de

main library for unconditional simulation of random fields

 Copyright (C) 2015 -- 2021 Martin Schlather

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 3
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/ 


#include "AutoRandomFieldsUtils.h"

const char

*R_TYPE_NAMES[LAST_R_TYPE_NAME + 1] = {
  "NILSXP" /* 0 */,
  "SYMSXP", "LISTSXP", "CLOSXP", "ENVSXP", "PROMSXP",
  "LANGSXP", "SPECIALSXP", "BUILTINSXP", "CHARSXP", "LGLSXP" /* 10 */,
  "??", "??", "INTSXP", "REALSXP", "CPLXSXP", "STRSXP", "DOTSXP", "ANYSXP",
  "ECSXP", "EXPRSXP" /*20 */,
  "BCODESXP", "EXTPTRSXP", "WEAKREFSXP", "RAWSXP", "S4SXP" /* 25 */, "", "", "",
  "", "NEWSXP" /* 30 */,
  "FREESXP", "??SXP"},

*LA_NAMES[LA_LAST + 1] = {"auto", "intern", "R", "GPU", "query"},

*PIVOT_NAMES[PIVOT_LAST + 1] = {"none", "auto", "do", "idx", "undefined"},

*INSTALL_NAMES[INSTALL_LAST + 1] = {"none", "ask", "install", 
				    "sse", "sse2", "sse3", "ssse3", "avx", "avx2",
				    "avx512f",
				    "gpu"};

==> RandomFieldsUtils_1.2.2.tar.gz: RandomFieldsUtils/src/AutoRandomFieldsUtils.cc <==
/*
Authors
Martin Schlather, schlather@math.uni-mannheim.de

main library for unconditional simulation of random fields

 Copyright (C) 2015 -- 2021 Martin Schlather

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 3
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/ 


#include "AutoRandomFieldsUtils.h"

const char

*R_TYPE_NAMES[LAST_R_TYPE_NAME + 1] = { // never change ! see kleinkram.cc
  "NILSXP" /* 0 */,
  "SYMSXP", "LISTSXP", "CLOSXP", "ENVSXP", "PROMSXP",
  "LANGSXP", "SPECIALSXP", "BUILTINSXP", "CHARSXP", "LGLSXP" /* 10 */,
  "??", "??", "INTSXP", "REALSXP", "CPLXSXP",
  "STRSXP", "DOTSXP", "ANYSXP", "ECSXP", "EXPRSXP" /*20 */,
  "BCODESXP", "EXTPTRSXP", "WEAKREFSXP", "RAWSXP", "S4SXP" /* 25 */,
  "", "", "", "", "NEWSXP" /* 30 */,
  "FREESXP", "??SXP"},

 *LA_NAMES[LA_LAST + 1] = { "intern", "R", "auto", "GPU", "query"},

*PIVOT_NAMES[PIVOT_LAST + 1] = {"no privoting",
  "do", "auto", "idx", "undefined"},

*INSTALL_NAMES[INSTALL_LAST + 1] = {"no installation", "install", "ask", 
				    "sse", "sse2", "sse3", "ssse3", "avx",
				    "avx2", "avx512f", "gpu"};
